==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/uk/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software: %1 %2</source>
        <translation>Програмне забезпечення: %1 %2</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Локальний час: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Інформація про програмне забезпечення</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Програмне забезпечення</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версія програмного забезпечення</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>ОС</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>Версія ОС</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Інформація про клієнт</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Дозволяє отримувати та надсилати інформацію про версію програмного забезпечення, локальний час та останню активність</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Підтримує обмін інформацією про версію програмного забезпечення</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Остання активність</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Підтримує обмін інформацією про останню активність користувача</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Локальний час</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Підтримує обмін інформацією про локальний час користувача</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Час роботи</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Час простою</translation>
    </message>
    <message>
        <source>Share information about OS version</source>
        <translation>Показувати інформацію про версію ОС</translation>
    </message>
    <message>
        <source>XMPP Ping</source>
        <translation>Пінг</translation>
    </message>
    <message>
        <source>Supports the exchanging of the application-level pings over XML streams</source>
        <translation>Підтримує XMPP ping</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Інформація про клієнт - %1</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Ім&apos;я:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>ОС:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Помилка:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Різниця:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Пінг, мс:</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версія програмного забезпечення</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Час роботи</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Остання активність</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Час простою</translation>
    </message>
    <message>
        <source>Uptime:</source>
        <translation>Час роботи:</translation>
    </message>
    <message>
        <source>Inactive:</source>
        <translation>Неактивний:</translation>
    </message>
    <message>
        <source>Idle:</source>
        <translation>Простоює:</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Локальний час</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступно</translation>
    </message>
    <message>
        <source>%1y</source>
        <comment>years</comment>
        <translation>%1р</translation>
    </message>
    <message>
        <source>%1d</source>
        <comment>days</comment>
        <translation>%1д</translation>
    </message>
    <message>
        <source>%1h</source>
        <comment>hours</comment>
        <translation>%1г</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>minutes</comment>
        <translation>%1хв</translation>
    </message>
    <message>
        <source>%1s</source>
        <comment>seconds</comment>
        <translation>%1с</translation>
    </message>
    <message>
        <source>Waiting response...</source>
        <translation>Очікування відповіді...</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/uk/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software: %1 %2</source>
        <translation>Програмне забезпечення: %1 %2</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Локальний час: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Інформація про програмне забезпечення</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Програмне забезпечення</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версія програмного забезпечення</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>ОС</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>Версія ОС</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Інформація про клієнт</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Дозволяє отримувати та надсилати інформацію про версію програмного забезпечення, локальний час та останню активність</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Підтримує обмін інформацією про версію програмного забезпечення</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Остання активність</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Підтримує обмін інформацією про останню активність користувача</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Локальний час</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Підтримує обмін інформацією про локальний час користувача</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Час роботи</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Час простою</translation>
    </message>
    <message>
        <source>Share information about OS version</source>
        <translation>Показувати інформацію про версію ОС</translation>
    </message>
    <message>
        <source>XMPP Ping</source>
        <translation>Пінг</translation>
    </message>
    <message>
        <source>Supports the exchanging of the application-level pings over XML streams</source>
        <translation>Підтримує обмін ping-ами на рівні програми через XMPP-з&apos;єднання</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Інформація про клієнт - %1</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Ім&apos;я:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>ОС:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Помилка:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Різниця:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Пінг, мс:</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версія програмного забезпечення</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Час роботи</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Остання активність</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Час простою</translation>
    </message>
    <message>
        <source>Uptime:</source>
        <translation>Час роботи:</translation>
    </message>
    <message>
        <source>Inactive:</source>
        <translation>Неактивний:</translation>
    </message>
    <message>
        <source>Idle:</source>
        <translation>Простоює:</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Локальний час</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступно</translation>
    </message>
    <message>
        <source>%1y</source>
        <comment>years</comment>
        <translation>%1р</translation>
    </message>
    <message>
        <source>%1d</source>
        <comment>days</comment>
        <translation>%1д</translation>
    </message>
    <message>
        <source>%1h</source>
        <comment>hours</comment>
        <translation>%1г</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>minutes</comment>
        <translation>%1хв</translation>
    </message>
    <message>
        <source>%1s</source>
        <comment>seconds</comment>
        <translation>%1с</translation>
    </message>
    <message>
        <source>Waiting response...</source>
        <translation>Очікування відповіді...</translation>
    </message>
</context>
</TS>
